#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class RenderingEnvironmentWall(AnyObject):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     RenderingEnvironmentWall
                | 
                | Represents a Environment object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.rendering_environment_wall = com_object

    @property
    def active_status(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ActiveStatus() As short
                | 
                |     Returns or sets the environment wall active status. A wall is visible only
                |     when it is active.
                | 
                |         The active status can be:
                |         1: wall is visible
                |         0: wall is invisible

        :rtype: int
        """

        return self.rendering_environment_wall.ActiveStatus

    @active_status.setter
    def active_status(self, value: int):
        """
        :param int value:
        """

        self.rendering_environment_wall.ActiveStatus = value

    @property
    def auto_scale_status(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AutoScaleStatus() As short
                | 
                |     Returns or sets the texture automatic scaling status. If status is
                |     automatic scaling, the texture fit is locked when the environment size is
                |     modified.
                | 
                |         The scaling status can be:
                |         1: automatic scaling is on
                |         0: automatic scaling is off

        :rtype: int
        """

        return self.rendering_environment_wall.AutoScaleStatus

    @auto_scale_status.setter
    def auto_scale_status(self, value: int):
        """
        :param int value:
        """

        self.rendering_environment_wall.AutoScaleStatus = value

    @property
    def flip_u_status(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property FlipUStatus() As short
                | 
                |     Returns or sets texture orientation status along the U
                |     axis.
                | 
                |         The flip status can be:
                |         1: texture is flipped along the U axis
                |         0: texture is not flipped along the U axis

        :rtype: int
        """

        return self.rendering_environment_wall.FlipUStatus

    @flip_u_status.setter
    def flip_u_status(self, value: int):
        """
        :param int value:
        """

        self.rendering_environment_wall.FlipUStatus = value

    @property
    def flip_v_status(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property FlipVStatus() As short
                | 
                |     Returns or sets texture orientation status along the V
                |     axis.
                | 
                |         The flip status can be:
                |         1: texture is flipped along the V axis
                |         0: texture is not flipped along the V axis

        :rtype: int
        """

        return self.rendering_environment_wall.FlipVStatus

    @flip_v_status.setter
    def flip_v_status(self, value: int):
        """
        :param int value:
        """

        self.rendering_environment_wall.FlipVStatus = value

    @property
    def linked_scale_status(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property LinkedScaleStatus() As short
                | 
                |     Returns or sets the texture scaling link status. If scales are linked,
                |     modifying one scale will update the other keeping the ratio between U and V
                |     constant.
                | 
                |         The link status can be:
                |         1: U and V scales are linked
                |         0: U and V scales are not linked

        :rtype: int
        """

        return self.rendering_environment_wall.LinkedScaleStatus

    @linked_scale_status.setter
    def linked_scale_status(self, value: int):
        """
        :param int value:
        """

        self.rendering_environment_wall.LinkedScaleStatus = value

    @property
    def rotation(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Rotation() As double
                | 
                |     Returns or sets the texture rotation angle (in degrees). The rotation
                |     values must be between -360 and 360 degrees.

        :rtype: float
        """

        return self.rendering_environment_wall.Rotation

    @rotation.setter
    def rotation(self, value: float):
        """
        :param float value:
        """

        self.rendering_environment_wall.Rotation = value

    @property
    def scale_u(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ScaleU() As double
                | 
                |     Returns or sets the texture scale along the U axis. The scale value should
                |     be > 0. Note that the modification of this parameter is useless if automatic
                |     scaling is enabled.

        :rtype: float
        """

        return self.rendering_environment_wall.ScaleU

    @scale_u.setter
    def scale_u(self, value: float):
        """
        :param float value:
        """

        self.rendering_environment_wall.ScaleU = value

    @property
    def scale_v(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ScaleV() As double
                | 
                |     Returns or sets the texture scale along the V axis. The scale value should
                |     be > 0. Note that the modification of this parameter is useless if automatic
                |     scaling is enabled.

        :rtype: float
        """

        return self.rendering_environment_wall.ScaleV

    @scale_v.setter
    def scale_v(self, value: float):
        """
        :param float value:
        """

        self.rendering_environment_wall.ScaleV = value

    @property
    def shadows_status(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ShadowsStatus() As short
                | 
                |     Returns or sets the wall shadow status. A wall may or may not be affected
                |     by lights depending on this status.
                | 
                |         The shadows status can be:
                |         1: wall is affected by active lights and can bear
                |         shadows
                |         0: wall is not affected by active lights and is always
                |         seen

        :rtype: int
        """

        return self.rendering_environment_wall.ShadowsStatus

    @shadows_status.setter
    def shadows_status(self, value: int):
        """
        :param int value:
        """

        self.rendering_environment_wall.ShadowsStatus = value

    @property
    def texture(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Texture() As CATBSTR
                | 
                |     Returns or sets the wall texture name. To remove the texture, use an empty
                |     string.

        :rtype: str
        """

        return self.rendering_environment_wall.Texture

    @texture.setter
    def texture(self, value: str):
        """
        :param str value:
        """

        self.rendering_environment_wall.Texture = value

    @property
    def translation_u(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property TranslationU() As double
                | 
                |     Returns or sets the texture offset along the U axis. Note that this
                |     parameter is useless if automatic scaling is enabled.

        :rtype: float
        """

        return self.rendering_environment_wall.TranslationU

    @translation_u.setter
    def translation_u(self, value: float):
        """
        :param float value:
        """

        self.rendering_environment_wall.TranslationU = value

    @property
    def translation_v(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property TranslationV() As double
                | 
                |     Returns or sets the texture offset along the V axis. Note that this
                |     parameter is useless if automatic scaling is enabled.

        :rtype: float
        """

        return self.rendering_environment_wall.TranslationV

    @translation_v.setter
    def translation_v(self, value: float):
        """
        :param float value:
        """

        self.rendering_environment_wall.TranslationV = value

    def fit_all_in_wall(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub FitAllInWall()
                | 
                |     If a texture is mapped on the wall, scale automatically the texture to fit
                |     inside the wall.

        :rtype: None
        """
        return self.rendering_environment_wall.FitAllInWall()

    def __repr__(self):
        return f'RenderingEnvironmentWall(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.kinematics_interfaces.joint import Joint
from pycatia.kinematics_interfaces.joints import Joints
from pycatia.kinematics_interfaces.mechanism_command import MechanismCommand
from pycatia.kinematics_interfaces.mechanism_commands import MechanismCommands
from pycatia.product_structure_interfaces.product import Product
from pycatia.system_interfaces.any_object import AnyObject


class Mechanism(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     Mechanism
                | 
                | Interface to access the Mechanism object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.mechanism = com_object

    @property
    def commands(self) -> MechanismCommands:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Commands() As MechanismCommands (Read Only)
                | 
                |     Returns the collection of commands in the mechanism.
                | 
                |     Parameters:
                | 
                |         oCommands
                |             The collection of commands. This property is read only because
                |             because list is aggregated in the Mechanism

        :rtype: MechanismCommands
        """

        return MechanismCommands(self.mechanism.Commands)

    @property
    def fixed_part(self) -> Product:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property FixedPart() As Product
                | 
                |     Returns or sets the fixed part of the mechanism.
                | 
                |     Parameters:
                | 
                |         oFixedPart
                |             The fixed part.

        :rtype: Product
        """

        return Product(self.mechanism.FixedPart)

    @fixed_part.setter
    def fixed_part(self, value: Product):
        """
        :param Product value:
        """

        self.mechanism.FixedPart = value

    @property
    def joints(self) -> Joints:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Joints() As Joints (Read Only)
                | 
                |     Returns the collection of joints in the mechanism.
                | 
                |     Parameters:
                | 
                |         oJoints
                |             The collection of joints. This property is read only because
                |             because list is aggregated in the Mechanism

        :rtype: Joints
        """

        return Joints(self.mechanism.Joints)

    @property
    def nb_commands(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property NbCommands() As long (Read Only)
                | 
                |     Returns the number of commands in the mechanism.
                | 
                |     Parameters:
                | 
                |         oNbCommands
                |             The number of commands. This property is read only because number
                |             depends on commands creation/destruction

        :rtype: int
        """

        return self.mechanism.NbCommands

    @property
    def nb_dof(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property NbDof() As long (Read Only)
                | 
                |     Returns the degree of freedom of the mechanism.
                | 
                |     Parameters:
                | 
                |         oNbDof
                |             The degree of freedom. This property is read only because because
                |             it depends on joints and commands

        :rtype: int
        """

        return self.mechanism.NbDof

    @property
    def nb_joints(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property NbJoints() As long (Read Only)
                | 
                |     Returns the number of joints in the mechanism.
                | 
                |     Parameters:
                | 
                |         oNbJoints
                |             The number of joints. This property is read only because number
                |             depends on joints creation/destruction

        :rtype: int
        """

        return self.mechanism.NbJoints

    @property
    def nb_products(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property NbProducts() As long (Read Only)
                | 
                |     Returns the number of products (i.e. bodies) involved in the
                |     mechanism.
                | 
                |     Parameters:
                | 
                |         oNbProducts
                |             The number of products. This property is read only because number
                |             depends on joints creation/destruction

        :rtype: int
        """

        return self.mechanism.NbProducts

    def add_command(self, i_cmd_type: str, i_joint: Joint) -> MechanismCommand:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddCommand(CATBSTR iCmdType,
                | Joint iJoint) As MechanismCommand
                | 
                |     Adds a command in the mechanism, on a joint.
                | 
                |     Parameters:
                | 
                |         iCmdType
                |             The command type. 
                |         iJoint
                |             The joint to be driven. 
                |         oNewCommand
                |             The newly created command.

        :param str i_cmd_type:
        :param Joint i_joint:
        :rtype: MechanismCommand
        """
        return MechanismCommand(self.mechanism.AddCommand(i_cmd_type, i_joint.com_object))

    def add_joint(self, i_joint_type: str, i_list_elem: tuple) -> Joint:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddJoint(CATBSTR iJointType,
                | CATSafeArrayVariant iListElem) As Joint
                | 
                |     Adds a joint in the mechanism.
                | 
                |     Parameters:
                | 
                |         iJointType
                |             The joint type. 
                |         iListElem
                |             The list of elements expected to locate the joint, depending on the
                |             type. 
                |         oNewJoint
                |             The newly created joint.

        :param str i_joint_type:
        :param tuple i_list_elem:
        :rtype: Joint
        """
        return Joint(self.mechanism.AddJoint(i_joint_type, i_list_elem))

    def get_command_values(self, io_cmd_values: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetCommandValues(CATSafeArrayVariant ioCmdValues)
                | 
                |     Allows to retrieve current state of the mechanism.
                | 
                |     Parameters:
                | 
                |         ioCmdValues
                |             current command values

        :param tuple io_cmd_values:
        :rtype: None
        """
        return self.mechanism.GetCommandValues(io_cmd_values)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_command_values'
        # # vba_code = """
        # # Public Function get_command_values(mechanism)
        # #     Dim ioCmdValues (2)
        # #     mechanism.GetCommandValues ioCmdValues
        # #     get_command_values = ioCmdValues
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_product(self, i_index: int) -> Product:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetProduct(long iIndex) As Product
                | 
                |     Returns an item from the list of the products involved in the
                |     mechanism.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index for the product. 
                |         oProduct
                |             The product at that index. 
                | 
                |     Returns:
                |         HRESULT

        :param int i_index:
        :rtype: Product
        """
        return Product(self.mechanism.GetProduct(i_index))

    def get_product_motion(self, i_product: Product, io_motion: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetProductMotion(Product iProduct,
                | CATSafeArrayVariant ioMotion)
                | 
                |     Retrieves motion from initial state to current state for a part of the
                |     mechanism.
                | 
                |     Parameters:
                | 
                |         iProduct
                |             The moving product 
                |         ioMotion
                |             The motion matrix (12 real values, compatible with the Move object)
                |             
                | 
                |     See also:
                |         Move

        :param Product i_product:
        :param tuple io_motion:
        :rtype: None
        """
        return self.mechanism.GetProductMotion(i_product.com_object, io_motion)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_product_motion'
        # # vba_code = """
        # # Public Function get_product_motion(mechanism)
        # #     Dim iProduct (2)
        # #     mechanism.GetProductMotion iProduct
        # #     get_product_motion = iProduct
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def put_command_values(self, i_cmd_values: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub PutCommandValues(CATSafeArrayVariant iCmdValues)
                | 
                |     Triggers immediate mechanism solving (motion is NOT applied to the
                |     model).
                | 
                |     Parameters:
                | 
                |         iCmdValues
                |             command values to be solved for

        :param tuple i_cmd_values:
        :rtype: None
        """
        return self.mechanism.PutCommandValues(i_cmd_values)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'put_command_values'
        # # vba_code = """
        # # Public Function put_command_values(mechanism)
        # #     Dim iCmdValues (2)
        # #     mechanism.PutCommandValues iCmdValues
        # #     put_command_values = iCmdValues
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def put_command_values_with_multi_steps(self, i_cmd_values: tuple, i_nb_steps: int, o_step_reached: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub PutCommandValuesWithMultiSteps(CATSafeArrayVariant
                | iCmdValues,
                | long iNbSteps,
                | long oStepReached)
                | 
                |     Puts command values in given number of steps. Visualization is updated
                |     after every step.
                | 
                |     Parameters:
                | 
                |         iCmdValues
                |             Array of target command values (position to achieve)
                |             
                |         inbSteps
                |             Number of steps in witch the target command value is to be
                |             reached.
                |             Legal values
                | 
                |             inbSteps greater than 0
                |                 Number of step must be greater than zero. 
                |             oStepReached
                |                 Number of steps reached successfully.

        :param tuple i_cmd_values:
        :param int i_nb_steps:
        :param int o_step_reached:
        :rtype: None
        """
        return self.mechanism.PutCommandValuesWithMultiSteps(i_cmd_values, i_nb_steps, o_step_reached)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'put_command_values_with_multi_steps'
        # # vba_code = """
        # # Public Function put_command_values_with_multi_steps(mechanism)
        # #     Dim iCmdValues (2)
        # #     mechanism.PutCommandValuesWithMultiSteps iCmdValues
        # #     put_command_values_with_multi_steps = iCmdValues
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def reset_cmd_value_to_zero(self, i_command: MechanismCommand) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ResetCmdValueToZero(MechanismCommand iCommand)
                | 
                |     Sets the command value to zero for the given command without disturbing
                |     part positions.
                | 
                |     Parameters:
                | 
                |         iCommand
                |             The command to reset to zero

        :param MechanismCommand i_command:
        :rtype: None
        """
        return self.mechanism.ResetCmdValueToZero(i_command.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'reset_cmd_value_to_zero'
        # # vba_code = """
        # # Public Function reset_cmd_value_to_zero(mechanism)
        # #     Dim iCommand (2)
        # #     mechanism.ResetCmdValueToZero iCommand
        # #     reset_cmd_value_to_zero = iCommand
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def update(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Update()
                | 
                |     Reassembles the mechanism after dimension changes in the parts.

        :rtype: None
        """
        return self.mechanism.Update()

    def __repr__(self):
        return f'Mechanism(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dmaps_interfaces.activity import Activity
from pycatia.dnb_igp_setup_interfaces.robot_motion import RobotMotion
from pycatia.system_interfaces.any_object import AnyObject


class Operation(Activity):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DMAPSInterfaces.Activity
                |                         Operation
                | 
                | Represents an Operation.
                | 
                | Role: The interface is used manage the activities under an Operation and its
                | attributes.
                | The following code snippet can be used to obtain an Operation from a Robot
                | Task.
                | 
                |    Dim objRobotTask as RobotTask
                |    Dim objOperationList As Operation
                |    objRobotTask.GetAllOperations objOperationList
                |    Dim objOperation As Operation
                |    objOperation=objOperationList[0]
                |
                | The Operation can also be obtained from an activity of the type
                | Operation.
                | 
                |    Dim objActivity as Activity
                |    ...
                |    Dim objOperation as Operation
                |    Set objOperation = objActivity.GetTechnologicalObject("Operation" )
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.operation = com_object

    def create_robot_motion(
            self,
            i_ref_act: AnyObject,
            i_before: bool,
            o_target_motion: RobotMotion
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub CreateRobotMotion(AnyObject iRefAct,
                | boolean iBefore,
                | RobotMotion oTargetMotion)
                | 
                |     Creates Robot Motion as a child of Operation. If there is an already
                |     existing RobotMotion we do not create a new one but return the handle to the
                |     existing one, else creates it at the start and link
                |     appropriately.
                | 
                |     Parameters:
                | 
                |         iRefAct
                |             Reference activity After/Before which the Target Motion needs to be
                |             created. 
                |         iBefore
                |             Created Target Motion can be Predecessor(True)/Successor(False) to
                |             Reference activity. 
                |         oTargetMotion
                |             The created Robot Motion. 
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             The Robot Motion could be successfully created
                |         E_FAIL
                |             The Robot Motion could not be created.
                | 
                |         Example:
                |             The following example creates a robot motion as a child of
                |             Operation.
                | 
                |                Dim objOperation As Operation
                |                Dim objRefAct as AnyObject
                |                Dim objRobotmotion as RobotMotion
                |                objOperation.CreateRobotMotion
                |                objRefAct,1,objRobotmotion

        :param AnyObject i_ref_act:
        :param bool i_before:
        :param RobotMotion o_target_motion:
        :rtype: None
        """
        return self.operation.CreateRobotMotion(i_ref_act.com_object, i_before, o_target_motion.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'create_robot_motion'
        # # vba_code = """
        # # Public Function create_robot_motion(operation)
        # #     Dim iRefAct (2)
        # #     operation.CreateRobotMotion iRefAct
        # #     create_robot_motion = iRefAct
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_actions(self, o_children_list: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetActions(CATSafeArrayVariant oChildrenList)
                | 
                |     Retrieves all the Basic Actions under the operation.
                | 
                |     Parameters:
                | 
                |         oChildrenList
                |             Returns the Basic Actions of the Robot 
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             The actions could be successfully queried
                |         E_FAIL
                |             The actions could not be queried.
                | 
                |         Example:
                |             The following example gets the actions of the current
                |             Operation.
                | 
                |                Dim objOperation As Operation
                |                Dim ActionList(2)
                |                objOperation.GetActions ActionList

        :param tuple o_children_list:
        :rtype: None
        """
        return self.operation.GetActions(o_children_list)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_actions'
        # # vba_code = """
        # # Public Function get_actions(operation)
        # #     Dim oChildrenList (2)
        # #     operation.GetActions oChildrenList
        # #     get_actions = oChildrenList
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_robot_motion(self, o_robot_target_motion: RobotMotion) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetRobotMotion(RobotMotion oRobotTargetMotion)
                | 
                |     Retrieves the RobotMotion.
                | 
                |     Parameters:
                | 
                |         oRobotTargetMotion
                |             Returned RobotMotion 
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             The Robot Motion could be successfully queried
                |         E_FAIL
                |             The Robot Motion could not be queried.
                | 
                |         Example:
                |             The following example gets the robot motion of the current
                |             Operation.
                | 
                |                Dim objOperation As Operation
                |                Dim objRobotmotion as RobotMotion
                |                objOperation.GetRobotMotion objRobotmotion

        :param RobotMotion o_robot_target_motion:
        :rtype: None
        """
        return self.operation.GetRobotMotion(o_robot_target_motion.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_robot_motion'
        # # vba_code = """
        # # Public Function get_robot_motion(operation)
        # #     Dim oRobotTargetMotion (2)
        # #     operation.GetRobotMotion oRobotTargetMotion
        # #     get_robot_motion = oRobotTargetMotion
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_via_mode(self, index: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetViaMode(short index)
                | 
                |     Retrieves the via mode of the operation.
                | 
                |     Parameters:
                | 
                |         index
                |             The Via Mode (1 if the target is a via point and 0 if the Target is
                |             Untyped (process)). 
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             The via mode was successfully queried.
                |         E_FAIL
                |             The via mode could not be queried.
                | 
                |         Example:
                |             The following example retrieves the Via Mode of the
                |             Operation.
                | 
                |                Dim objOperation As Operation
                |                Dim ViaMode
                |                objOperation.GetViaMode ViaMode

        :param int index:
        :rtype: None
        """
        return self.operation.GetViaMode(index)

    def set_via_mode(self, index: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetViaMode(short index)
                | 
                |     Sets the Via Mode of the Operation.
                | 
                |     Parameters:
                | 
                |         index
                |             The Via Mode (1 if the target is a via point and 0 if the Target is
                |             Untyped (process)). 
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             The via mode was successfully set.
                |         E_FAIL
                |             The via mode could not be set.
                | 
                |         Example:
                |             The following example sets the Via Mode of the
                |             Operation.
                | 
                |                Dim objOperation As Operation
                |                objOperation.SetViaMode 0

        :param int index:
        :rtype: None
        """
        return self.operation.SetViaMode(index)

    def __repr__(self):
        return f'Operation(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_sch_platform_interfaces.sch_route import SchRoute
from pycatia.in_interfaces.document import Document
from pycatia.system_interfaces.any_object import AnyObject


class SchAppRoute(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SchAppRoute
                | 
                | Manage a schematic route.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sch_app_route = com_object

    def app_break(self) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AppBreak() As AnyObject
                | 
                |     Break the application route into 2 routes.
                | 
                |     Parameters:
                | 
                |         oNewAppRoute
                |             New application route 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchAppRoute
                |          Dim objArg1 As AnyObject
                |           ...
                |          Set objArg1 = objThisIntf.AppBreak

        :rtype: AnyObject
        """
        return AnyObject(self.sch_app_route.AppBreak())

    def app_create_local_reference(self, i_document_to_put_copy_in: Document) -> 'SchAppRoute':
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AppCreateLocalReference(Document iDocumentToPutCopyIn) As
                | SchAppRoute
                | 
                |     Make a local route reference in another document by copying an existing one
                |     in the current document.
                | 
                |     Parameters:
                | 
                |         iDocumentToPutCopyIn
                |             Pointer to the document to make the copy in 
                |         oSchAppRoute
                |             Pointer to the copy. 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppRoute
                |          Dim objArg1 As Document
                |          Dim objArg2 As SchAppRoute
                |           ...
                |          Set objArg2 = objThisIntf.AppCreateLocalReference(objArg1)

        :param Document i_document_to_put_copy_in:
        :rtype: SchAppRoute
        """
        return SchAppRoute(self.sch_app_route.AppCreateLocalReference(i_document_to_put_copy_in.com_object))

    def app_ok_to_branch(self, i_branch_class_type: str, o_b_yes: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppOKToBranch(CATBSTR iBranchClassType,
                | boolean oBYes)
                | 
                |     Query whether it is OK to create branch.
                | 
                |     Parameters:
                | 
                |         iBranchClassType
                |             Class type of the branch to create. 
                |         oBYes
                |             If TRUE, then it is OK to create a branch from an application route
                |
                |     Example:
                | 
                |          Dim objThisIntf As SchAppRoute
                |          Dim strVar1 As String
                |          Dim bVar2 As boolean
                |           ...
                |          objThisIntf.AppOKToBranchstrVar1,bVar2

        :param str i_branch_class_type:
        :param bool o_b_yes:
        :rtype: None
        """
        return self.sch_app_route.AppOKToBranch(i_branch_class_type, o_b_yes)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'app_ok_to_branch'
        # # vba_code = """
        # # Public Function app_ok_to_branch(sch_app_route)
        # #     Dim iBranchClassType (2)
        # #     sch_app_route.AppOKToBranch iBranchClassType
        # #     app_ok_to_branch = iBranchClassType
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def app_ok_to_break(self, o_b_yes: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppOKToBreak(boolean oBYes)
                | 
                |     Query whether it is OK to break.
                | 
                |     Parameters:
                | 
                |         oBYes
                |             If TRUE, then it is OK to break the application route
                |             
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppRoute
                |          Dim bVar1 As boolean
                |           ...
                |          objThisIntf.AppOKToBreakbVar1

        :param bool o_b_yes:
        :rtype: None
        """
        return self.sch_app_route.AppOKToBreak(o_b_yes)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'app_ok_to_break'
        # # vba_code = """
        # # Public Function app_ok_to_break(sch_app_route)
        # #     Dim oBYes (2)
        # #     sch_app_route.AppOKToBreak oBYes
        # #     app_ok_to_break = oBYes
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def app_ok_to_concatenate(self, o_b_yes: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppOKToConcatenate(boolean oBYes)
                | 
                |     Query whether it is OK to concatenate.
                | 
                |     Parameters:
                | 
                |         oBYes
                |             If TRUE, then it is OK to concatenate the application route with
                |             another 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchAppRoute
                |          Dim bVar1 As boolean
                |           ...
                |          objThisIntf.AppOKToConcatenatebVar1

        :param bool o_b_yes:
        :rtype: None
        """
        return self.sch_app_route.AppOKToConcatenate(o_b_yes)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'app_ok_to_concatenate'
        # # vba_code = """
        # # Public Function app_ok_to_concatenate(sch_app_route)
        # #     Dim oBYes (2)
        # #     sch_app_route.AppOKToConcatenate oBYes
        # #     app_ok_to_concatenate = oBYes
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def app_ok_to_modify_points(self, o_b_yes: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppOKToModifyPoints(boolean oBYes)
                | 
                |     Query whether it is OK to modify (add or remove) the
                |     points.
                | 
                |     Parameters:
                | 
                |         oBYes
                |             If TRUE, then it is OK to add or remove the points from the
                |             application route 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchAppRoute
                |          Dim bVar1 As boolean
                |           ...
                |          objThisIntf.AppOKToModifyPointsbVar1

        :param bool o_b_yes:
        :rtype: None
        """
        return self.sch_app_route.AppOKToModifyPoints(o_b_yes)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'app_ok_to_modify_points'
        # # vba_code = """
        # # Public Function app_ok_to_modify_points(sch_app_route)
        # #     Dim oBYes (2)
        # #     sch_app_route.AppOKToModifyPoints oBYes
        # #     app_ok_to_modify_points = oBYes
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def app_post_break_process(self, i_old_app_route: SchRoute, i_new_app_route: SchRoute) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppPostBreakProcess(SchRoute iOldAppRoute,
                | SchRoute iNewAppRoute)
                | 
                |     Post process after breaking an application route into 2
                |     pieces.
                | 
                |     Parameters:
                | 
                |         iOldAppRoute
                |             The old application route object 
                |         iNewAppRoute
                |             The new Application route object 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchAppRoute
                |          Dim objArg1 As SchRoute
                |          Dim objArg2 As SchRoute
                |           ...
                |          objThisIntf.AppPostBreakProcessobjArg1,objArg2

        :param SchRoute i_old_app_route:
        :param SchRoute i_new_app_route:
        :rtype: None
        """
        return self.sch_app_route.AppPostBreakProcess(i_old_app_route.com_object, i_new_app_route.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'app_post_break_process'
        # # vba_code = """
        # # Public Function app_post_break_process(sch_app_route)
        # #     Dim iOldAppRoute (2)
        # #     sch_app_route.AppPostBreakProcess iOldAppRoute
        # #     app_post_break_process = iOldAppRoute
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def app_post_concatenate_process(self, i_sch_route2: SchRoute) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppPostConcatenateProcess(SchRoute iSchRoute2)
                | 
                |     Post process after concatenate 2 application routes into
                |     one.
                | 
                |     Parameters:
                | 
                |         iSchRoute2
                |             Second route to be concatenate to this. This route will be deleted.
                |
                |     Example:
                |
                |          Dim objThisIntf As SchAppRoute
                |          Dim objArg1 As SchRoute
                |           ...
                |          objThisIntf.AppPostConcatenateProcessobjArg1

        :param SchRoute i_sch_route2:
        :rtype: None
        """
        return self.sch_app_route.AppPostConcatenateProcess(i_sch_route2.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'app_post_concatenate_process'
        # # vba_code = """
        # # Public Function app_post_concatenate_process(sch_app_route)
        # #     Dim iSchRoute2 (2)
        # #     sch_app_route.AppPostConcatenateProcess iSchRoute2
        # #     app_post_concatenate_process = iSchRoute2
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'SchAppRoute(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.funct_system_interfaces.functional_action import FunctionalAction
from pycatia.system_interfaces.any_object import AnyObject
from pycatia.types.general import cat_variant


class FunctActionsGroup(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     FunctActionsGroup
                | 
                | The interface to access a group of functional actions in a
                | system.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.funct_actions_group = com_object

    @property
    def actions_count(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ActionsCount() As long (Read Only)
                | 
                |     Get the count of actions referenced by the actions' group.

        :rtype: int
        """

        return self.funct_actions_group.ActionsCount

    def add(self, i_action: FunctionalAction) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Add(FunctionalAction iAction)
                | 
                |     Adds an action to the actions' group.
                | 
                |     Fails if the action :
                | 
                |         is already in a group
                |         has "From" and "To" extremities inconsistent with the existing actions.
                |         
                | 
                |     In case of an ordered group, the added action will be
                |     appended.
                |     (i.e. for flows sequencing actions)
                | 
                |     Parameters:
                | 
                |         iAction
                |             The action to be added to the group of actions.

        :param FunctionalAction i_action:
        :rtype: None
        """
        return self.funct_actions_group.Add(i_action.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add'
        # # vba_code = """
        # # Public Function add(funct_actions_group)
        # #     Dim iAction (2)
        # #     funct_actions_group.Add iAction
        # #     add = iAction
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_extremities(self, o_input_x: float, o_input_y: float, o_output_x: float, o_output_y: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetExtremities(double oInputX,
                | double oInputY,
                | double oOutputX,
                | double oOutputY)
                | 
                |     Get coordinates of Input and Output extremities.

        :param float o_input_x:
        :param float o_input_y:
        :param float o_output_x:
        :param float o_output_y:
        :rtype: None
        """
        return self.funct_actions_group.GetExtremities(o_input_x, o_input_y, o_output_x, o_output_y)

    def remove(self, i_action: FunctionalAction) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Remove(FunctionalAction iAction)
                | 
                |     Removes an action from the actions' group.
                | 
                |     Parameters:
                | 
                |         iAction
                |             The action to be removed from the group of
                |             actions.

        :param FunctionalAction i_action:
        :rtype: None
        """
        return self.funct_actions_group.Remove(i_action.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove'
        # # vba_code = """
        # # Public Function remove(funct_actions_group)
        # #     Dim iAction (2)
        # #     funct_actions_group.Remove iAction
        # #     remove = iAction
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def remove_position(self, i_position: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemovePosition(long iPosition)
                | 
                |     Removes an action from the actions' group.
                | 
                |     Parameters:
                | 
                |         iPosition
                |             The position of the action to be removed from the group of
                |             actions.

        :param int i_position:
        :rtype: None
        """
        return self.funct_actions_group.RemovePosition(i_position)

    def retrieve(self, i_index: cat_variant) -> FunctionalAction:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Retrieve(CATVariant iIndex) As FunctionalAction
                | 
                |     Returns an action using its index or its name from the actions
                |     group.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the action to retrieve from the group of
                |             actions. As a numerics, this index is the rank of the action in the group. The
                |             index of the first action in the group is 1, and the index of the last action
                |             is Count. As a string, it is the name you assigned to the action using the
                |             
                | 
                |         AnyObject.Name property. 
                |     Returns:
                |         The retrieved action 
                |     Example:
                |         This example retrieves in Obj1 the fifth action in the group and in
                |         Obj2 the action named Valve.
                | 
                |          Dim Act1 As FunctionalAction
                |          Set Act1 = ActionsGrp.Retrieve(5)
                |          Dim Act2 As FunctionalAction
                |          Set Act2 = ActionsGrp.Retrieve("Reduces noise")

        :param cat_variant i_index:
        :rtype: FunctionalAction
        """
        return FunctionalAction(self.funct_actions_group.Retrieve(i_index))

    def set_extremities(self, i_input_x: float, i_input_y: float, i_output_x: float, i_output_y: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetExtremities(double iInputX,
                | double iInputY,
                | double iOutputX,
                | double iOutputY)
                | 
                |     Set coordinates of Input and Output extremities.

        :param float i_input_x:
        :param float i_input_y:
        :param float i_output_x:
        :param float i_output_y:
        :rtype: None
        """
        return self.funct_actions_group.SetExtremities(i_input_x, i_input_y, i_output_x, i_output_y)

    def __repr__(self):
        return f'FunctActionsGroup(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_sch_platform_interfaces.sch_component import SchComponent
from pycatia.system_interfaces.any_object import AnyObject


class SchUpdateInstances(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SchUpdateInstances
                | 
                | Interface to update all component instances when the catalog reference
                | component has been changed.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sch_update_instances = com_object

    def update_all_instances_from_reference(self, i_comp_local_ref: SchComponent) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub UpdateAllInstancesFromReference(SchComponent
                | iCompLocalRef)
                | 
                |     Update all the instances of a given local reference in a document. Both the
                |     local reference and all its instances will be updated to account for any
                |     changes in the corresponding catalog reference.
                | 
                |     Example:
                | 
                |           This example illustrates how to update all the schematic component
                |           instances
                |          in the active document by selecting any one of the instances or their
                |          local reference.
                |          
                | 
                |          ' --- get SchUpdateInstances interface
                |          Dim objCurrentDoc As Document
                |          Dim objPrdRoot As Product
                |          Dim objSchRoot As SchematicRoot
                |          Dim objUpdateInstances As SchUpdateInstances
                |          Set objCurrentDoc = CATIA.ActiveDocument
                |          Set objPrdRoot = objCurrentDoc.Product
                |          Set objSchRoot = objPrdRoot.GetTechnologicalObject ("SchematicRoot")
                |          Set objUpdateInstances = objSchRoot.GetInteface ("CATIASchUpdateInstances",objCurrentDoc)
                | 
                |          ' --- get the local reference 
                |          Dim objPrdInst As Product
                |          Dim objPrdRef As Product
                |          Dim objCompRef As SchComponent
                |          ' --- get an instance, objPrdInst from the selected set of
                |          objects
                |          Set objPrdInst = objCurrentDoc.Selection.FindObject("CATIAProduct")
                |          Set objPrdRef = objPrdInst.ReferenceProduct
                |          Set objCompRef = objSchRoot.GetInterface ("CATIASchComponent",objPrdRef)
                | 
                |          ' --- update all the instances
                |          objUpdateInstances.UpdateAllInstancesFromReference
                |          objCompRef

        :param SchComponent i_comp_local_ref:
        :rtype: None
        """
        return self.sch_update_instances.UpdateAllInstancesFromReference(i_comp_local_ref.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'update_all_instances_from_reference'
        # # vba_code = """
        # # Public Function update_all_instances_from_reference(sch_update_instances)
        # #     Dim iCompLocalRef (2)
        # #     sch_update_instances.UpdateAllInstancesFromReference iCompLocalRef
        # #     update_all_instances_from_reference = iCompLocalRef
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'SchUpdateInstances(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.arrangement_interfaces.arrangement_rectangle import ArrangementRectangle
from pycatia.in_interfaces.move import Move
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class ArrangementRectangles(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     ArrangementRectangles
                | 
                | A Collection object for ArrangementRectangle objects.
                | Role: Use this object to manage (create, retrieve and remove)
                | ArrangementRectangle objects.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=ArrangementRectangle)
        self.arrangement_rectangles = com_object

    def add_rectangle(
            self,
            i_rel_axis: Move,
            i_position: tuple,
            i_width: float,
            i_length: float
    ) -> ArrangementRectangle:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddRectangle(Move iRelAxis,
                | CATSafeArrayVariant iPosition,
                | double iWidth,
                | double iLength) As ArrangementRectangle
                | 
                |     Creates an ArrangementRectangle and adds it to the
                |     collection.
                | 
                |     Parameters:
                | 
                |         iRelAxis
                |             Relative Axis to be considered. 
                |         iPosition
                |             Position information for the Rectangle (rotation and location).
                |             
                |         iWidth
                |             Width of the Rectangle. 
                |         iLength
                |             Length of the Rectangle. 
                | 
                |     Returns:
                |         Returns the newly created ArrangementRectangle and adds it to the
                |         collection.

        :param Move i_rel_axis:
        :param tuple i_position:
        :param float i_width:
        :param float i_length:
        :rtype: ArrangementRectangle
        """
        return ArrangementRectangle(
            self.arrangement_rectangles.AddRectangle(i_rel_axis.com_object, i_position, i_width, i_length))

    def item(self, i_index: cat_variant) -> ArrangementRectangle:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex) As ArrangementRectangle
                | 
                |     Returns the specified ArrangementRectangle item of the collection
                |     object.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the ArrangementRectangle to retrieve from
                |             this collection.
                | 
                |             To retrieve a specific object by number, use the rank of the
                |             ArrangementRectangle in that collection.
                |                 Note that the index of the first element in the collection is
                |                 1, and the index of the last element is Count. To retrieve a specific
                |                 ArrangementRectangle by name, use name that you assigned using the
                |                 
                | 
                |         AnyObject.Name property. 
                |     Returns:
                |         The retrieved ArrangementRectangle object.

        :param cat_variant i_index:
        :rtype: ArrangementRectangle
        """
        return ArrangementRectangle(self.arrangement_rectangles.Item(i_index))

    def remove(self, i_index: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Remove(CATVariant iIndex)
                | 
                |     Removes the specified ArrangementRectangle object from the
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the ArrangementRectangle to remove from
                |             this collection.
                | 
                |             To remove a specific object by number, use the rank of the
                |             ArrangementRectangle in that collection.
                |                 Note that the index of the first element in the collection is
                |                 1, and the index of the last element is Count. To remove a specific
                |                 ArrangementRectangle by name, use name that you assigned using the
                |                 
                | 
                |         AnyObject.Name property.

        :param cat_variant i_index:
        :rtype: None
        """
        return self.arrangement_rectangles.Remove(i_index)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove'
        # # vba_code = """
        # # Public Function remove(arrangement_rectangles)
        # #     Dim iIndex (2)
        # #     arrangement_rectangles.Remove iIndex
        # #     remove = iIndex
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'ArrangementRectangles(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_plant_ship_interfaces.psp_group import PSPGroup
from pycatia.cat_plant_ship_interfaces.psp_list_of_objects import PSPListOfObjects


class PSPLogicalLine(PSPGroup):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     CATPlantShipInterfaces.PspGroup
                |                         PspLogicalLine
                | 
                | Represents the logical line.
                | Role: To query the logical line object's from/to members.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.psp_logical_line = com_object

    def get_from_to(
            self,
            o_list_from_major: PSPListOfObjects,
            o_list_from_minor: PSPListOfObjects,
            o_list_to_major: PSPListOfObjects,
            o_list_to_minor: PSPListOfObjects
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetFromTo(PspListOfObjects oListFromMajor,
                | PspListOfObjects oListFromMinor,
                | PspListOfObjects oListToMajor,
                | PspListOfObjects oListToMinor)
                | 
                |     Retrieves the lists of major and minor from/to members from this
                |     line.
                |     The members retrieved are all PspGroupable objects.
                | 
                |     Parameters:
                | 
                |         oListFromMajor
                |             The list of major from members 
                |         oListFromMinor
                |             The list of minor from members 
                |         oListToMajor
                |             The list of major to members 
                |         oListToMinor
                |             The list of minor to members 
                | 
                |     Example:
                |
                |          Dim objThisIntf As PspLogicalLine  
                |          Dim objArg1 As PspListOfObjects
                |          Dim objArg2 As PspListOfObjects
                |          Dim objArg3 As PspListOfObjects
                |          Dim objArg4 As PspListOfObjects
                |          ...
                |          objThisIntf.GetFromTo objArg1, objArg2, objArg3,
                |          objArg4

        :param PSPListOfObjects o_list_from_major:
        :param PSPListOfObjects o_list_from_minor:
        :param PSPListOfObjects o_list_to_major:
        :param PSPListOfObjects o_list_to_minor:
        :rtype: None
        """
        return self.psp_logical_line.GetFromTo(
            o_list_from_major.com_object,
            o_list_from_minor.com_object,
            o_list_to_major.com_object,
            o_list_to_minor.com_object
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_from_to'
        # # vba_code = """
        # # Public Function get_from_to(psp_logical_line)
        # #     Dim oListFromMajor (2)
        # #     psp_logical_line.GetFromTo oListFromMajor
        # #     get_from_to = oListFromMajor
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_from_to_info_array_max_size(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetFromToInfoArrayMaxSize() As long
                | 
                |     Returns the maximum possible size of the from-to
                |     information.
                | 
                |     Returns:
                |         The maximum possible size of the array to hold the information returned
                |         by GetFromToInformation
                |
                |     Example:
                |
                |          Dim objThisIntf As PspLogicalLine  
                |          Dim intValueMaxSize As Integer
                |          ...
                |          intValueMaxSize = objThisIntf.GetFromToInfoArrayMaxSize

        :rtype: int
        """
        return self.psp_logical_line.GetFromToInfoArrayMaxSize()

    def get_from_to_information(
            self,
            o_from_to_label: tuple,
            o_ft_major: tuple,
            o_ft_minor: tuple,
            o_size_of_output: int
    ) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetFromToInformation(CATSafeArrayVariant oFromToLabel,
                | CATSafeArrayVariant oFTMajor,
                | CATSafeArrayVariant oFTMinor,
                | long oSizeOfOutput)
                | 
                |     Retrieves the from/to information of a logical line.
                | 
                |     Parameters:
                | 
                |         oFromToLabel
                |             The array of labels ("From" or "To") 
                |         oFTMajor
                |             The array of from/to major IDs 
                |         oFTMinor
                |             The array of from/to minor IDs 
                |         The
                |             size of the output arrays 
                | 
                |     Example:
                |
                |          Dim objThisIntf As PspLogicalLine  
                |          Dim strFromToLabel(20) As String
                |          Dim strFromToMajor(20) As String
                |          Dim strFromToMinor(20) As String
                |          Dim intValueMaxSize As Integer
                |          intValueMaxSize = objThisIntf.GetFromToInfoArrayMaxSize
                |          ... 
                |          '----  make sure the array size if big enough
                |          If (intValueMaxSize ≤ 20)  Then
                |             objThisIntf.GetFromToInformation _
                |               strFromToLabel, strFromToMajor, strFromToMinor,
                |               intValueMaxSize
                |          End If
                | 
                |          The following table can then be filled with the output
                |          arrays.
                |          
                |             From/To        |   F/T Major       |    F/T Minor
                |          strFromToLabel(i) | strFromToMajor(i) | 
                |          strFromToMinor(i)

        :param tuple o_from_to_label:
        :param tuple o_ft_major:
        :param tuple o_ft_minor:
        :param int o_size_of_output:
        :rtype: String
        """
        return self.psp_logical_line.GetFromToInformation(o_from_to_label, o_ft_major, o_ft_minor, o_size_of_output)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_from_to_information'
        # # vba_code = """
        # # Public Function get_from_to_information(psp_logical_line)
        # #     Dim oFromToLabel (2)
        # #     psp_logical_line.GetFromToInformation oFromToLabel
        # #     get_from_to_information = oFromToLabel
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'PSPLogicalLine(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dnb_igp_setup_interfaces.robot_task import RobotTask
from pycatia.product_structure_interfaces.product import Product
from pycatia.system_interfaces.any_object import AnyObject


class OLPTranslator(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     OLPTranslator
                | 
                | Represents the Offline Programming Translator object.
                | Role: Interface dedicated to downloading or uploading robot or device tasks and
                | formatting the output in the specified native robot language.
                | 
                | This object can be retrieved by querying on a Robot. For
                | example:
                | 
                |  Dim SelectionObject as Selection
                |  Dim RobotObject As Product
                |  Dim OLPTranslatorObject as OLPTranslator
                |  Set SelectionObject = DELMIA.ActiveDocument.Selection
                |  Set RobotObject = SelectionObject.Item2(1).Value
                |  Set OLPTranslatorObject = RobotObject.GetTechnologicalObject("OLPTranslator")
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.olp_translator = com_object

    def convert_nrl_to_xml(self, i_nrl_file_name: str, i_parser_name: str, o_xml_file_name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ConvertNRLToXML(CATBSTR iNRLFileName,
                | CATBSTR iParserName,
                | CATBSTR oXMLFileName)
                | 
                |     Converts NRL Program to OLP XML upload file
                | 
                |     Parameters:
                | 
                |         iNRLFileName
                |             Input NRL Robot program file. 
                |         iParserName
                |             Path to Robot program parser.
                |             Legal values:
                | 
                |                 Java parser packaged as Jar
                |                 A native parser packaged as an executable
                | 
                |         oXMLFileName
                |             Target XML output file

        :param str i_nrl_file_name:
        :param str i_parser_name:
        :param str o_xml_file_name:
        :rtype: None
        """
        return self.olp_translator.ConvertNRLToXML(i_nrl_file_name, i_parser_name, o_xml_file_name)

    def convert_xml_to_nrl(self, i_xml_file_name: str, i_xslt_file_name: str, o_nrl_target_folder: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ConvertXMLToNRL(CATBSTR iXMLFileName,
                | CATBSTR iXSLTFileName,
                | CATBSTR oNRLTargetFolder)
                | 
                |     Converts OLP XML download file to NRL Program
                | 
                |     Parameters:
                | 
                |         iXMLFileName
                |             Input XML file. 
                |         iXSLTFileName
                |             Translator file name 
                |         oNRLTargetFolder
                |             Target folder where the robot programs will be saved. Name of the
                |             program files will be auto generated.

        :param str i_xml_file_name:
        :param str i_xslt_file_name:
        :param str o_nrl_target_folder:
        :rtype: None
        """
        return self.olp_translator.ConvertXMLToNRL(i_xml_file_name, i_xslt_file_name, o_nrl_target_folder)

    def download_as_xml(
            self,
            i_robot_task: RobotTask,
            o_xml_file_name: str,
            i_is_part_coordinates: bool,
            i_is_simulated: bool,
            i_is_sub_routines: bool
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub DownloadAsXML(RobotTask iRobotTask,
                | CATBSTR oXMLFileName,
                | boolean iIsPartCoordinates,
                | boolean iIsSimulated,
                | boolean iIsSubRoutines)
                | 
                |     Downloads a Robot task as XML file
                | 
                |     Parameters:
                | 
                |         iRobotTask
                |             The robot task to download 
                |         oXMLFileName
                |             Name of XML file to be generated 
                |         iIsPartCoordinates
                |             if TRUE, the robot task will be downloaded in part coordinates of
                |             iPart if FALSE, the robot task will be downloaded in robot base coordinates
                |             
                |         iIsSimulated
                |             if TRUE, Download will be simulation verified 
                |         iIsSubRoutines
                |             if TRUE, XML will have tags marking call tasks for download as
                |             subroutines in main program file if FALSE, XML will have tags marking call
                |             tasks for download as separate files

        :param RobotTask i_robot_task:
        :param str o_xml_file_name:
        :param bool i_is_part_coordinates:
        :param bool i_is_simulated:
        :param bool i_is_sub_routines:
        :rtype: None
        """
        return self.olp_translator.DownloadAsXML(
            i_robot_task.com_object,
            o_xml_file_name,
            i_is_part_coordinates,
            i_is_simulated,
            i_is_sub_routines
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'download_as_xml'
        # # vba_code = """
        # # Public Function download_as_xml(olp_translator)
        # #     Dim iRobotTask (2)
        # #     olp_translator.DownloadAsXML iRobotTask
        # #     download_as_xml = iRobotTask
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def download_tasks(
            self,
            l_list_of_tasks: tuple,
            s_path_to_xslt_translator: str,
            s_context: str,
            b_is_part_coordinates: bool,
            b_is_subroutine: bool,
            s_log_file_name: str
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub DownloadTasks(CATSafeArrayVariant lListOfTasks,
                | CATBSTR sPathToXSLTTranslator,
                | CATBSTR sContext,
                | boolean bIsPartCoordinates,
                | boolean bIsSubroutine,
                | CATBSTR sLogFileName)
                | 
                |     Creates native robot language programs from V5 tasks. First the V5 Robot
                |     Offline Programming XML is generated for the given robot or device tasks in
                |     non-simulation mode. Then the XML file is supplied to the XSLT translator to
                |     create output in the corresponding native robot language.
                |     Role: Used to translate specified robot/device tasks to native robot
                |     language program(s). It is responsibility of specified xslt translator to
                |     provide the mechanism for saving its output to one or more
                |     files.
                | 
                |     Parameters:
                | 
                |         lListOfTasks
                |             List of robot or list of device tasks to download 
                |         sPathToXSLTTranslator
                |             Absolute path to XSLT translator (downloader).If this is an empty
                |             string, no XSLT translation will be done, and only OLP XML file will be
                |             created. 
                |         sContext
                |             Value that defines a context in which an XSLT translator works.
                |             This tells the translator how to format the output. Internally, the XSLT
                |             translator should have a mechanism in place on how to format its output based
                |             on this value. This value is user defined and it may impact user developed
                |             downloaders as well as RRS2 custom created downloaders. Any value of this
                |             parameter, rather the supplied default value, will be assigned to the "Context"
                |             attribute of the "OLPData" XML element. Translators should check whether the
                |             "Context" attribute exists in the "OLPData" XML element, and if it does, they
                |             should redirect the XSLT output accordingly. If the attribute does not exist,
                |             which means that the translator has been invoked during execution of "Create
                |             Robot Program" interactive command, then the translators should use OLP section
                |             markers in order to display their output in V5.
                | 
                |             Here are the section marker rules that need to be strictly
                |             followed: It is important that the entire robot program output, designated to
                |             be saved in a particular file, is enclosed between DATA FILE START and DATA
                |             FILE END markers. Translator output without any DATA FILE START and DATA FILE
                |             END elements will be displayed in one tab page, generically named "Program.1".
                |             If translator output has DATA FILE START and DATA FILE END elements (multiple
                |             pairs),but without , each enclosed section of the output will go into a
                |             separate tab page named "Program.1", "Program.2",
                |             etc.
                | 
                |             Every downloader should use ERROR INFO START ERROR INFO END
                |             elements to store any error messages, in order to display them in the
                |             information text box of Download Editor.
                | 
                |             As with error messages, release and version information will be
                |             copied from the output's VERSION INFO START VERSION INFO END markers and will
                |             be displayed in the information text box of Download
                |             Editor.
                | 
                |             All of the marker elements need to start at the beginning of a new
                |             line and to end with a new line character. The examples are
                |             below:
                | 
                |             DATA FILE START myProgram.1 ... DATA FILE END
                | 
                |             VERSION INFO START Delmia Corp. NachiAX Uploader Version 5 Release
                |             15. Copyright Delmia Corp. 1986-2003, All Rights Reserved. VERSION INFO
                |             END
                | 
                |             ERROR INFO START The error occurred during translation of Motion.1
                |             activity ERROR INFO END 
                |         bIsPartCoordinates
                |             Flag that signifies whether the download of the tasks should be in
                |             Part or Robot Base coordinates (important for a robot motion activity only).
                |             
                |         bIsSubroutine
                |             Flag that signifies whether a called Robot Task (important for call
                |             task activities only) should be downloaded as a subroutine of a main robot
                |             program, or as a separate program contained in a separate file.
                |             
                |         sLogFileName
                |             Name of the log file that an XSLT translator can use to write data
                |             to. An empty string signifies that log file is not needed. It is important to
                |             note that this is just a file name, not an absolute path to that file. This log
                |             file is supposed to be saved to a directory which is a descendant of a
                |             downloader root directory. Downloader root directory is defined in the XML
                |             through the "DownloaderRootDirectory" attribute of the "OLPData" XML
                |             element.

        :param tuple l_list_of_tasks:
        :param str s_path_to_xslt_translator:
        :param str s_context:
        :param bool b_is_part_coordinates:
        :param bool b_is_subroutine:
        :param str s_log_file_name:
        :rtype: None
        """
        return self.olp_translator.DownloadTasks(
            l_list_of_tasks,
            s_path_to_xslt_translator,
            s_context,
            b_is_part_coordinates,
            b_is_subroutine,
            s_log_file_name
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'download_tasks'
        # # vba_code = """
        # # Public Function download_tasks(olp_translator)
        # #     Dim lListOfTasks (2)
        # #     olp_translator.DownloadTasks lListOfTasks
        # #     download_tasks = lListOfTasks
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_robot_program_directory(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetRobotProgramDirectory() As CATBSTR
                | 
                |     Retrieves the OLP Directory setting parameter value.
                |     Role: The OLP Directory setting parameter stores the full file path to
                |     directory where native robot language programs will be
                |     stored.
                | 
                |     Returns:
                |         The OLP Directory setting parameter value

        :rtype: str
        """
        return self.olp_translator.GetRobotProgramDirectory()

    def get_xml_file_directory(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetXMLFileDirectory() As CATBSTR
                | 
                |     Retrieves the XML Directory setting parameter value.
                |     Role: The XML Directory setting parameter stores the full file path to
                |     directory where OLP XML file created on download is stored. By default, OLP XML
                |     file name is simResult.xml.
                | 
                |     Returns:
                |         The XML Directory setting parameter value

        :rtype: str
        """
        return self.olp_translator.GetXMLFileDirectory()

    def upload_from_xml(
            self,
            i_robot_task: RobotTask,
            i_xml_file_name: str,
            i_is_part_coordinates: bool,
            i_part: Product
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub UploadFromXML(RobotTask iRobotTask,
                | CATBSTR iXMLFileName,
                | boolean iIsPartCoordinates,
                | Product iPart)
                | 
                |     Upload a Robot task from XML file
                | 
                |     Parameters:
                | 
                |         iRobotTask
                |             Robot task to upload 
                |         iXMLFileName
                |             Name of source XML file 
                |         iIsPartCoordinates
                |             if TRUE, Robot task will be uploaded in part coordinates of iPart
                |             if FALSE, Robot task will be uploaded in robot base coordinates
                |             
                |         iPart
                |             Part in whose coordinates the program will be
                |             uploaded

        :param RobotTask i_robot_task:
        :param str i_xml_file_name:
        :param bool i_is_part_coordinates:
        :param Product i_part:
        :rtype: None
        """
        return self.olp_translator.UploadFromXML(
            i_robot_task.com_object,
            i_xml_file_name,
            i_is_part_coordinates,
            i_part.com_object
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'upload_from_xml'
        # # vba_code = """
        # # Public Function upload_from_xml(olp_translator)
        # #     Dim iRobotTask (2)
        # #     olp_translator.UploadFromXML iRobotTask
        # #     upload_from_xml = iRobotTask
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def upload_robot_program(
            self,
            sp_i_selected_robot: Product,
            s_path_to_robot_program_file: str,
            s_path_to_uploader_file: str,
            b_is_upload_in_part_coords: bool
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub UploadRobotProgram(Product spISelectedRobot,
                | CATBSTR sPathToRobotProgramFile,
                | CATBSTR sPathToUploaderFile,
                | boolean bIsUploadInPartCoords)
                | 
                |     Creates robot or device tasks in V5 based from native robot language
                |     program file or an OLP XML file.
                |     Role: To be used to create specified robot/device tasks from native robot
                |     language program file(s) or from OLP XML file.
                | 
                |     Parameters:
                | 
                |         spISelectedRobot
                |             Robot or Move-By-Joint Device, which will own all the uploaded
                |             robot or device tasks 
                |         sPathToRobotProgramFile
                |             Absolute path to a native robot language (NRL) program file or an
                |             absolute path to OLP XML file to be uploaded 
                |         sPathToUploaderFile
                |             Absolute path to OLP uploader file. If this is specified as an
                |             empty string, the previous parameter must point to an OLP XML file. If this
                |             string is not empty, the previous parameter must point to an NRL program file.
                |             
                |         bIsUploadInPartCoords
                |             Flag that signifies whether the upload of robot programs(s) or XML
                |             file should be in Part or Robot Base coordinates (important for robot motion
                |             activities only).

        :param Product sp_i_selected_robot:
        :param str s_path_to_robot_program_file:
        :param str s_path_to_uploader_file:
        :param bool b_is_upload_in_part_coords:
        :rtype: None
        """
        return self.olp_translator.UploadRobotProgram(
            sp_i_selected_robot.com_object,
            s_path_to_robot_program_file,
            s_path_to_uploader_file,
            b_is_upload_in_part_coords
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'upload_robot_program'
        # # vba_code = """
        # # Public Function upload_robot_program(olp_translator)
        # #     Dim spISelectedRobot (2)
        # #     olp_translator.UploadRobotProgram spISelectedRobot
        # #     upload_robot_program = spISelectedRobot
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'OLPTranslator(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.cat_mat_interfaces.analysis_material import AnalysisMaterial
from pycatia.cat_rma_interfaces.rendering_material import RenderingMaterial
from pycatia.system_interfaces.any_object import AnyObject


class Material(AnyObject):
    """
    .. note::
        :class: toggle

        CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

            | System.IUnknown
            |     System.IDispatch
            |         System.CATBaseUnknown
            |             System.CATBaseDispatch
            |                 System.AnyObject
            |                     Material
            |
            | Represents a Material object.

    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.material = com_object

    @property
    def analysis_material(self) -> AnalysisMaterial:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AnalysisMaterial() As AnalysisMaterial (Read Only)
                |
                |     Returns the analysis material object from the current
                |     material.

        :rtype: AnalysisMaterial
        """
        return AnalysisMaterial(self.material.AnalysisMaterial)

    @property
    def rendering_material(self) -> RenderingMaterial:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property RenderingMaterial() As RenderingMaterial (Read
                | Only)
                |
                |     Returns the rendering material object from the current
                |     material.

        :rtype: RenderingMaterial
        """
        return RenderingMaterial(self.material.RenderingMaterial)

    def copy_rendering_data_from(self, i_rendering_material: RenderingMaterial) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub CopyRenderingDataFrom(RenderingMaterial
                | iRenderingMaterial)
                |
                |     Copy rendering data from a material to the current
                |     material.

        :param RenderingMaterial i_rendering_material:
        :rtype: None
        """
        return self.material.CopyRenderingDataFrom(i_rendering_material.com_object)

    def create_analysis_data(self, i_label: str) -> AnalysisMaterial:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func CreateAnalysisData(CATBSTR iLabel) As
                | AnalysisMaterial
                |
                |     Create a default analysis material on the current
                |     material.

        :param str i_label:
        :rtype: AnalysisMaterial
        """
        return AnalysisMaterial(self.material.CreateAnalysisData(i_label))

    def create_rendering_data(self) -> RenderingMaterial:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func CreateRenderingData() As RenderingMaterial
                |
                |     Create a default rendering material on the current
                |     material.

        :rtype: RenderingMaterial
        """
        return RenderingMaterial(self.material.CreateRenderingData())

    def exist_analysis_data(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ExistAnalysisData() As short
                |
                |     Returns true if a analysis material exists on the current
                |     material.

        :rtype: int
        """
        return self.material.ExistAnalysisData()

    def exist_rendering_data(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ExistRenderingData() As short
                |
                |     Returns true if a rendering material exists on the current
                |     material.

        :rtype: int
        """
        return self.material.ExistRenderingData()

    def get_icon(self, i_path: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetIcon(CATBSTR iPath)
                | 
                |     Write the icon of a material to disc. The parameter is the
                |     path of the folder where the JPEG is going to be written
                |     Ex : E:\\folder\\

        :param str i_path:
        :rtype: None
        """
        return self.material.GetIcon(i_path)

    def put_icon(self, i_path: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub PutIcon(CATBSTR iPath)
                | 
                |     Read the icon of a material from JPEG file. The parameter
                |     is the path of the folder where the JPEG is going to be
                |     read Ex : E:\\folder\\

        :param str i_path:
        :rtype: None
        """
        return self.material.PutIcon(i_path)

    def __repr__(self):
        return f'Material(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class TCPTraceManagerGraphics(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     TCPTraceManagerGraphics
                | 
                | Interface used to modify the default graphical properties of TCP
                | traces.
                | 
                | Role: This interface is used to overload the next TCP traces and points
                | graphical properties.
                | 
                | A TCP trace is the graphical output of a task simulation. This output is the
                | trajectory path generated by the TCP, defined by lines and points. Each point
                | represents the location of the TCP at a given time.
                | 
                | The following code snippet can be used to obtain a handle from a
                | product:
                | 
                |    Dim MyRobot As Product
                |    'retrieval of the product
                |    ...
                | 
                |    'retrieval of the trace manager
                |    Dim objDevice As TCPTraceManagerGraphics
                |    set objDevice = MyRobot.GetTechnologicalObject("TCPTraceManagerGraphics")
                |    
                |    Dim iR As Long
                |    Dim iG As Long
                |    Dim iB As Long
                |    Dim iA As Long
                |    
                |    'activate the trace
                |    objDevice.SetTraceNextColor DNBTCPTraceRepLine,iR,iG,iB,iA
                |
                | See also:
                |     TCPTrace 
                | See also:
                |     TCPTraceManager
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.tcp_trace_manager_graphics = com_object

    def set_next_thickness(self, i_rep: int, i_thickness: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetNextThickness(DNBTCPTraceReps iRep,
                | long iThickness)
                | 
                |     Set the TCP trace component (DNBTCPTraceReps) thickness(for line, axis) for
                |     new points.This method does not modify the type for the complete path (as
                |     TCPTrace.SetThickness does). Instead, it changes the current type to apply for
                |     newly created points. This method is usefull, when the user interrupts the
                |     simulation and want to render differently the next points to be
                |     created.
                | 
                |     Parameters:
                | 
                |         iRep
                |             DNBTCPTraceReps. Define the graphical object the method will be
                |             applied on. Input parameter. 
                |         iThickness
                |             Indicates the index width of the line in the range [1,55]. This
                |             index is pointing on the true width in pixel, recorded in the standard (if
                |             there is one in the document) or in the setting. Input parameter.

        :param int i_rep: enum dnbtcp_trace_reps
        :param int i_thickness:
        :rtype: None
        """
        return self.tcp_trace_manager_graphics.SetNextThickness(i_rep, i_thickness)

    def set_next_type(self, i_rep: int, i_type: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetNextType(DNBTCPTraceReps iRep,
                | long iType)
                | 
                |     Set the TCP trace component (DNBTCPTraceReps) type for new points. This
                |     method does not modify the type for the complete path (as TCPTrace.SetType
                |     does). Instead, it changes the current type to apply for newly created points.
                |     This method is usefull, when the user interrupts the simulation and want to
                |     render differently the next points to be created. For points, legal values are
                |     :
                | 
                |         1 : CROSS
                |         2 : PLUS
                |         3 : CONCENTRIC
                | 
                |     For line and axis, legal values are :
                | 
                |         1 : solid
                |         2 : dotted
                |         3 : dashed
                |         4 : dot-dashed
                |         5 : phantom
                | 
                |     Call < to see the changes applied.
                | 
                |     Parameters:
                | 
                |         iRep
                |             DNBTCPTraceReps. Define the graphical object the method will be
                |             applied on. Input parameter. 
                |         iType
                |             Long.Depends on the DNBTCPTraceReps. Input parameter.
                |
                |     Returns:
                |         HRESULT Returns S_OK if it succeeds, otherwise E_FAIL.

        :param int i_rep: enum dnbtcp_trace_reps
        :param int i_type:
        :rtype: None
        """
        return self.tcp_trace_manager_graphics.SetNextType(i_rep, i_type)

    def set_trace_next_colour(self, i_rep: int, i_r: int, i_g: int, i_b: int, i_a: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetTraceNextColor(DNBTCPTraceReps iRep,
                | long iR,
                | long iG,
                | long iB,
                | long iA)
                | 
                |     Set the TCP trace component (DNBTCPTraceReps) color for new points. This
                |     method does not modify the complete color path (as TCPTrace.SetColor does).
                |     Instead, it changes the current color to apply for newly created points. This
                |     method is usefull, when the user interrupts the simulation and want to render
                |     differently the next points to be created.
                | 
                |     Parameters:
                | 
                |         iRep
                |             DNBTCPTraceReps. Define the graphical object the method will be
                |             applied on. Input parameter. 
                |         iR
                |             Long. Red color component from 0 to 255. Input parameter.
                |             
                |         iG
                |             Long. Green color component from 0 to 255. Input parameter.
                |             
                |         iB
                |             Long. Blue color component from 0 to 255. Input parameter.
                |             
                |         iA
                |             Long. Alpha color component from 0 to 255. Input parameter.

        :param int i_rep: enum dnbtcp_trace_reps
        :param int i_r:
        :param int i_g:
        :param int i_b:
        :param int i_a:
        :rtype: None
        """
        return self.tcp_trace_manager_graphics.SetTraceNextColor(i_rep, i_r, i_g, i_b, i_a)

    def __repr__(self):
        return f'TCPTraceManagerGraphics(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dnb_robot_interfaces.tcp_trace import TCPTrace
from pycatia.system_interfaces.any_object import AnyObject


class TCPTraceManager(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     TCPTraceManager
                | 
                | Interface representing an accessor to TCP traces object from a
                | product.
                | 
                | Role: This interface is used to retrieve TCP traces from a product. This
                | product is the assembly node representing the inverse kinematics
                | assembly.
                | 
                | A TCP trace is the graphical output of a task simulation. This output is the
                | trajectory path generated by the TCP, defined by lines and points. Each point
                | represents the location of the TCP at a given time.
                | 
                | The following code snippet can be used to obtain a handle from a
                | product:
                | 
                |    Dim MyRobot As Product
                |    'retrieval of the product
                |    ...
                | 
                |    'retrieval of the trace manager
                |    Dim objDevice As TCPTraceManager
                |    set objDevice = MyRobot.GetTechnologicalObject("TCPTraceManager")
                |    
                |    'activate the trace
                |    objDevice.TCPTraceMode=True
                | 
                |    'Get the last path
                |    Dim NbPath As Long
                |    NbPath = objDevice.GetNbPath
                |    If NbPath>0 Then
                |       ' retrieval of the last trace
                |       Dim RobotTCPTrace As TCPTrace
                |       Set RobotTCPTrace = objDevice.GetPath(NbPath)
                | 
                |       'Export the trace points
                |       RobotTCPTrace.Export("C:/TEMP/DEBUG.xls")
                |    End If
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.tcp_trace_manager = com_object

    @property
    def init_status(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property InitStatus() As boolean
                | 
                |     Indicates whether the tracing capability must delete previous traces when
                |     the simulation starts.
                | 
                |         True: previous traces are deleted
                |         False: previous traces are kept
                | 
                |     Parameters:
                | 
                |         oInitStatus
                |             Boolean. Indicates if the tracing capability is activ or
                |             not.

        :rtype: bool
        """

        return self.tcp_trace_manager.InitStatus

    @init_status.setter
    def init_status(self, value: bool):
        """
        :param bool value:
        """

        self.tcp_trace_manager.InitStatus = value

    @property
    def tcp_trace_mode(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property TCPTraceMode() As boolean
                | 
                |     Indicates if the tracing capability is activ or not.
                | 
                |         True: tracing capability activated
                |         False: tracing capability deactivated
                | 
                |     Parameters:
                | 
                |         oTCPTraceMode
                |             Boolean. Indicates if the tracing capability is activ or
                |             not.

        :rtype: bool
        """

        return self.tcp_trace_manager.TCPTraceMode

    @tcp_trace_mode.setter
    def tcp_trace_mode(self, value: bool):
        """
        :param bool value:
        """

        self.tcp_trace_manager.TCPTraceMode = value

    def get_attached_owner(self) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAttachedOwner() As AnyObject
                | 
                |     Retrieves the default attached owner of the trace. By default, the owner of
                |     the trace is the robot assembly node. If the robot is moved, the trace will
                |     follow. However, in some scenarios, the trace might be drawn related to another
                |     product (or even with respect to the world) like for example when dealing with
                |     a workpiece positioner.
                | 
                |     Parameters:
                | 
                |         oOwner
                |             CATIABase. Attached owner of the trace. Output parameter. Returns
                |             nothing if the trace is defined related to the world

        :rtype: AnyObject
        """
        return AnyObject(self.tcp_trace_manager.GetAttachedOwner())

    def get_nb_path(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetNbPath() As long
                | 
                |     Get the number of TCP trace.
                | 
                |     Parameters:
                | 
                |         oNb
                |             Long. Number of traces. Output parameter.

        :rtype: int
        """
        return self.tcp_trace_manager.GetNbPath()

    def get_path(self, i_index: int) -> TCPTrace:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetPath(long iIndex) As TCPTrace
                | 
                |     Get the iIndex path(trace)(starting at 1).
                | 
                |     Parameters:
                | 
                |         iIndex
                |             Long. Path/Trace index starting at 1. Input parameter.
                |             
                |         oTCPPath
                |             DNBIATCPTrace. Pointer on the trace. Output parameter.

        :param int i_index:
        :rtype: TCPTrace
        """
        return TCPTrace(self.tcp_trace_manager.GetPath(i_index))

    def remove_all_path(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemoveAllPath()
                | 
                |     Remove all traces from the current resource. All traces associated with the
                |     current resource will be removed from the 3D and deleted.

        :rtype: None
        """
        return self.tcp_trace_manager.RemoveAllPath()

    def remove_path_by_index(self, i_index: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemovePathByIndex(long iIndex)
                | 
                |     Remove a specific path based on its position in the list. The trace will be
                |     removed from the 3D viewer and deleted.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             Long. Position index starting at 1. Must be positiv. Input
                |             parameter.

        :param int i_index:
        :rtype: None
        """
        return self.tcp_trace_manager.RemovePathByIndex(i_index)

    def remove_path_by_object(self, tcp_path: TCPTrace) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemovePathByObject(TCPTrace TCPPath)
                | 
                |     Remove a specific trace based on the object. The trace will be removed from
                |     the 3D viewer and deleted.
                | 
                |     Parameters:
                | 
                |         TCPPath
                |             DNBIATCPTrace. Path to be removed.

        :param TCPTrace tcp_path:
        :rtype: None
        """
        return self.tcp_trace_manager.RemovePathByObject(tcp_path.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove_path_by_object'
        # # vba_code = """
        # # Public Function remove_path_by_object(tcp_trace_manager)
        # #     Dim TCPPath (2)
        # #     tcp_trace_manager.RemovePathByObject TCPPath
        # #     remove_path_by_object = TCPPath
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def reset_attached_owner(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ResetAttachedOwner()
                | 
                |     Resets the attached owner of the trace to the world. When a new trace will
                |     be created, it will defined with respect to the world.
                |     Remark: this will not change the exported values.

        :rtype: None
        """
        return self.tcp_trace_manager.ResetAttachedOwner()

    def set_attached_owner(self, i_owner: AnyObject) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAttachedOwner(AnyObject iOwner)
                | 
                |     Sets the default attached owner of the trace. By default, the owner of the
                |     trace is the robot. When a new trace is created, the attached owner is used to
                |     set it upon the trace.
                |     Remark: set the attached owner will not change the exported
                |     values.
                | 
                |     Parameters:
                | 
                |         iOwner
                |             CATIABase. Attached owner of the trace. Input parameter.

        :param AnyObject i_owner:
        :rtype: None
        """
        return self.tcp_trace_manager.SetAttachedOwner(i_owner.com_object)

    def __repr__(self):
        return f'TCPTraceManager(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_sch_platform_interfaces.sch_grr_route import SchGRRRoute
from pycatia.cat_sch_platform_interfaces.sch_list_of_objects import SchListOfObjects
from pycatia.system_interfaces.any_object import AnyObject


class SchRouteGraphic(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SchRouteGraphic
                | 
                | Manage graphical primitives representing a schematic route.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sch_route_graphic = com_object

    def add_graphical_primitive(self, i_grr_to_add: SchGRRRoute) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddGraphicalPrimitive(SchGRRRoute iGRRToAdd)
                | 
                |     Add a graphical primitive to a route.
                | 
                |     Parameters:
                | 
                |         iGRRToAdd
                |             The route graphical primitive to be added to the route.
                |
                |     Example:
                |
                |          Dim objThisIntf As SchRouteGraphic
                |          Dim objArg1 As SchGRRRoute
                |           ...
                |          objThisIntf.AddGraphicalPrimitiveobjArg1

        :param SchGRRRoute i_grr_to_add:
        :rtype: None
        """
        return self.sch_route_graphic.AddGraphicalPrimitive(i_grr_to_add.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_graphical_primitive'
        # # vba_code = """
        # # Public Function add_graphical_primitive(sch_route_graphic)
        # #     Dim iGRRToAdd (2)
        # #     sch_route_graphic.AddGraphicalPrimitive iGRRToAdd
        # #     add_graphical_primitive = iGRRToAdd
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def list_graphical_primitives(self) -> SchListOfObjects:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ListGraphicalPrimitives() As SchListOfObjects
                | 
                |     List all graphical primitives of a route.
                | 
                |     Parameters:
                | 
                |         oLGRR
                |             A list of graphical primitives (members are CATISchGRRRoute
                |             interface pointers). 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchRouteGraphic
                |          Dim objArg1 As SchListOfObjects
                |           ...
                |          Set objArg1 = objThisIntf.ListGraphicalPrimitives

        :rtype: SchListOfObjects
        """
        return SchListOfObjects(self.sch_route_graphic.ListGraphicalPrimitives())

    def remove_all_graphical_primitives(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemoveAllGraphicalPrimitives()
                | 
                |     Remove all graphical primitives of a route, including alternate graphical
                |     primitives.
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchRouteGraphic
                |           ...
                |          objThisIntf.RemoveAllGraphicalPrimitives

        :rtype: None
        """
        return self.sch_route_graphic.RemoveAllGraphicalPrimitives()

    def remove_graphical_primitive(self, i_grr_to_remove: SchGRRRoute) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemoveGraphicalPrimitive(SchGRRRoute iGRRToRemove)
                | 
                |     Remove a graphical primitive from a route.
                | 
                |     Parameters:
                | 
                |         iGRRToRemove
                |             The route graphical primitive to be removed from the component.
                |
                |     Example:
                |
                |          Dim objThisIntf As SchRouteGraphic
                |          Dim objArg1 As SchGRRRoute
                |           ...
                |          objThisIntf.RemoveGraphicalPrimitiveobjArg1

        :param SchGRRRoute i_grr_to_remove:
        :rtype: None
        """
        return self.sch_route_graphic.RemoveGraphicalPrimitive(i_grr_to_remove.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove_graphical_primitive'
        # # vba_code = """
        # # Public Function remove_graphical_primitive(sch_route_graphic)
        # #     Dim iGRRToRemove (2)
        # #     sch_route_graphic.RemoveGraphicalPrimitive iGRRToRemove
        # #     remove_graphical_primitive = iGRRToRemove
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'SchRouteGraphic(name="{self.name}")'



_vba_nothing = '''
Function N()        
    set N = Nothing        
End Function
'''


class VBANothing(str):

    def __init__(self, vba_code):
        self.vba_code = vba_code

    def __str__(self):
        return self.vba_code


vba_nothing = VBANothing(_vba_nothing)



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-09 09:53:18.676780

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.setting_controller import SettingController


class GlobalStatisticsSettingAtt(SettingController):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     System.SettingController
                |                         GlobalStatisticsSettingAtt
                | 
                | Interface for Global statistic Controller
                | Role: the global statistics controller manages the values of all or only a part
                | of the attributes available for all the statistics thematics.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.global_statistics_setting_att = com_object

    @property
    def buffer_size(self):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780)
                | o Property BufferSize() As long
                | 
                |     Returns or sets the size of buffer.
                |     Role: Returns or sets the size of the buffer.
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on Failure

        :return: int
        """

        return self.global_statistics_setting_att.BufferSize

    @buffer_size.setter
    def buffer_size(self, value):
        """
        :param int value:
        """

        self.global_statistics_setting_att.BufferSize = value

    @property
    def copy_directory(self):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780)
                | o Property CopyDirectory() As CATBSTR
                | 
                |     Returns or sets the path of the copy directory.
                |     Role: Returns or sets the path of the directory where the copy files are
                |     located.
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on Failure

        :return: str
        """

        return self.global_statistics_setting_att.CopyDirectory

    @copy_directory.setter
    def copy_directory(self, value):
        """
        :param str value:
        """

        self.global_statistics_setting_att.CopyDirectory = value

    @property
    def max_copy_file(self):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780)
                | o Property MaxCopyFile() As long
                | 
                |     Returns or sets the maximum number of copy files.
                |     Role: Returns or sets the value of the maximum number of statistics files
                |     copies.
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on Failure

        :return: int
        """

        return self.global_statistics_setting_att.MaxCopyFile

    @max_copy_file.setter
    def max_copy_file(self, value):
        """
        :param int value:
        """

        self.global_statistics_setting_att.MaxCopyFile = value

    @property
    def max_size_per_file(self):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780)
                | o Property MaxSizePerFile() As long
                | 
                |     Returns or sets the maximum size per file.
                |     Role: Returns or sets the value of the maximum size of statistics
                |     files.
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on Failure

        :return: int
        """

        return self.global_statistics_setting_att.MaxSizePerFile

    @max_size_per_file.setter
    def max_size_per_file(self, value):
        """
        :param int value:
        """

        self.global_statistics_setting_att.MaxSizePerFile = value

    def get_thematics_parameter_info(self, admin_level, o_locked):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780))
                | o Func GetThematicsParameterInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves environment informations for the global statistics
                |     parameters.
                |     Refer to SettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :return: None
        """
        return self.global_statistics_setting_att.GetThematicsParameterInfo(admin_level, o_locked)

    def set_thematics_parameter_lock(self, i_locked):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780))
                | o Sub SetThematicsParameterLock(boolean iLocked)
                | 
                |     Locks or unlocks the global statistics parameters.
                |     Role:Locks or unlocks the global statistics parameters.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on Failure

        :param bool i_locked:
        :return: None
        """
        return self.global_statistics_setting_att.SetThematicsParameterLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_thematics_parameter_lock'
        # # vba_code = """
        # # Public Function set_thematics_parameter_lock(global_statistics_setting_att)
        # #     Dim iLocked (2)
        # #     global_statistics_setting_att.SetThematicsParameterLock iLocked
        # #     set_thematics_parameter_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'GlobalStatisticsSettingAtt(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.hybrid_shape_interfaces.plane import Plane
from pycatia.in_interfaces.reference import Reference


class HybridShapePlane3Points(Plane):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.HybridShape
                |                         CATGSMIDLItf.Plane
                |                             HybridShapePlane3Points
                | 
                | Represents the hybrid shape plane through three points feature
                | object.
                | Role: Allows to access data of the plane feature passing though three points.
                | This data includes:
                | 
                |     The first point
                |     The second point
                |     The third point
                | 
                | Use the CATIAHybridShapeFactory to create HybridShapeFeature
                | object.
                | 
                | See also:
                |     HybridShapeFactory
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hybrid_shape_plane3_points = com_object

    @property
    def first(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property First() As Reference
                | 
                |     Returns or sets the first point.
                |     Sub-element(s) supported (see Boundary object): Vertex.
                | 
                |     Example: This example retrieves in FirstPoint the first point for the Plane
                |     passing through three points hybrid shape feature.
                | 
                |      Dim FirstPoint As Reference
                |      Set FirstPoint = Plane3Points.First

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_plane3_points.First)

    @first.setter
    def first(self, reference_point: Reference):
        """
        :param Reference reference_point:
        """

        self.hybrid_shape_plane3_points.First = reference_point.com_object

    @property
    def second(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Second() As Reference
                | 
                |     Returns or sets the second point.
                |     Sub-element(s) supported (see Boundary object): Vertex.
                | 
                |     Example: This example retrieves in SecondPoint the second point for the
                |     Plane passing through three points hybrid shape feature.
                | 
                |      Dim SecondPoint As Reference
                |      Set SecondPoint = Plane3Points.Second

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_plane3_points.Second)

    @second.setter
    def second(self, reference_point: Reference):
        """
        :param Reference reference_point:
        """

        self.hybrid_shape_plane3_points.Second = reference_point.com_object

    @property
    def third(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Third() As Reference
                | 
                |     Returns or sets the third point.
                |     Sub-element(s) supported (see Boundary object): Vertex.
                | 
                |     Example: This example retrieves in ThirdPoint the third point for the Plane
                |     passing through three points hybrid shape feature.
                | 
                |      Dim ThridPoint As Reference
                |      Set ThirdPoint = Plane3Points.Third

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_plane3_points.Third)

    @third.setter
    def third(self, reference_point: Reference):
        """
        :param Reference reference_point:
        """

        self.hybrid_shape_plane3_points.Third = reference_point

    def __repr__(self):
        return f'HybridShapePlane3Points(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.fitting_interfaces.shots import Shots
from pycatia.system_interfaces.any_object import AnyObject


class Sampled(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     Sampled
                | 
                | The interface to access a CATIASampled based object.
                | The Sampled class defines characteristics for simulatable tasks within DMU
                | Fitting. CATIASampled is the parent class for tracks. Key samples are recorded
                | (as shots or CATIAShots) for an object and then during simulation the object is
                | interpolated with these shots over time.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sampled = com_object

    @property
    def interpolater(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Interpolater() As CATBSTR
                | 
                |     Retrieves/sets the sampled's interpolater. Role: Retrieves/sets the
                |     interpolator used by the sampled during simulation. Note that the name of the
                |     interpolater is used (which is a string).

        :rtype: str
        """

        return self.sampled.Interpolater

    @interpolater.setter
    def interpolater(self, value: str):
        """
        :param str value:
        """

        self.sampled.Interpolater = value

    @property
    def object(self) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Object() As CATBaseDispatch
                | 
                |     Returns or sets the Sampled object. Role:/b> Retrieves/stores the object
                |     that will be used in the sampled based simulation. Please note that the object
                |     will move to the shots defined in the sampled.

        :rtype: AnyObject
        """

        return AnyObject(self.sampled.Object)

    @object.setter
    def object(self, value: AnyObject):
        """
        :param AnyObject value:
        """

        self.sampled.Object = value

    @property
    def scaling(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Scaling() As double
                | 
                |     Returns or sets the Sampled object.

        :rtype: float
        """

        return self.sampled.Scaling

    @scaling.setter
    def scaling(self, value: float):
        """
        :param float value:
        """

        self.sampled.Scaling = value

    @property
    def shots(self) -> Shots:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Shots() As Shots (Read Only)
                | 
                |     Returns or sets the Sampled object.

        :rtype: Shots
        """

        return Shots(self.sampled.Shots)

    @property
    def time(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Time() As double
                | 
                |     Retrieves/sets the sampled's time. Role: Retrieves/sets the internal time
                |     associated to the current sampled object. Note that the time is handled as a
                |     double.

        :rtype: float
        """

        return self.sampled.Time

    @time.setter
    def time(self, value: float):
        """
        :param float value:
        """

        self.sampled.Time = value

    def append(self, i_tracks: tuple) -> 'Sampled':
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Append(CATSafeArrayVariant iTracks) As Sampled
                | 
                |     Returns or sets the Sampled object.

        :param tuple i_tracks:
        :rtype: Sampled
        """
        return Sampled(self.sampled.Append(i_tracks))

    def bind_analysis(self, i_object: AnyObject, i_analysis_mode: int, i_monitor_mode: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub BindAnalysis(CATBaseDispatch iObject,
                | CatSampledAnalysisMode iAnalysisMode,
                | boolean iMonitorMode)
                | 
                |     Add (bind) an analysis object to a Track.
                | 
                |     Parameters:
                | 
                |         iObject
                |             The analysis to add (bind) to the Track 
                |         iAnalysisMode
                |             Indicates the analysis status for iAnalysis CatSampledAnalysisOff
                |             CatSampledAnalysisOn, CatSampledAnalysisStop CatSampledAnalysisVerbose
                |             
                |         iMonitorMode
                |             Indicates the monitor status for iAnalysis - Off (0) or On
                |             (1)

        :param AnyObject i_object:
        :param int i_analysis_mode: enum cat_sampled_analysis_mode
        :param bool i_monitor_mode:
        :rtype: None
        """
        return self.sampled.BindAnalysis(i_object.com_object, i_analysis_mode, i_monitor_mode)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'bind_analysis'
        # # vba_code = """
        # # Public Function bind_analysis(sampled)
        # #     Dim iObject (2)
        # #     sampled.BindAnalysis iObject
        # #     bind_analysis = iObject
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def break_inheritance(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub BreakInheritance()
                | 
                |     Returns or sets the Sampled object.

        :rtype: None
        """
        return self.sampled.BreakInheritance()

    def get_known_interpolaters(self, o_interpolaters: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetKnownInterpolaters(CATSafeArrayVariant
                | oInterpolaters)
                | 
                |     Returns or sets the Sampled object.

        :param tuple o_interpolaters:
        :rtype: None
        """
        return self.sampled.GetKnownInterpolaters(o_interpolaters)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_known_interpolaters'
        # # vba_code = """
        # # Public Function get_known_interpolaters(sampled)
        # #     Dim oInterpolaters (2)
        # #     sampled.GetKnownInterpolaters oInterpolaters
        # #     get_known_interpolaters = oInterpolaters
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_total_duration(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetTotalDuration() As double
                | 
                |     Returns the total duration

        :rtype: float
        """
        return self.sampled.GetTotalDuration()

    def remove_analyses(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemoveAnalyses()
                | 
                |     Returns or sets the Sampled object.

        :rtype: None
        """
        return self.sampled.RemoveAnalyses()

    def reverse_time(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ReverseTime()
                | 
                |     Returns or sets the Sampled object.

        :rtype: None
        """
        return self.sampled.ReverseTime()

    def set_object_keeping_position(self, i_object: AnyObject) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetObjectKeepingPosition(CATBaseDispatch iObject)
                | 
                |     Sets the object in the sampled. Role: Stores the object that will be used
                |     in the sampled based simulation. The object will not move and the sample's
                |     shots will be repositioned relative to the object position.

        :param AnyObject i_object:
        :rtype: None
        """
        return self.sampled.SetObjectKeepingPosition(i_object.com_object)

    def split(self, i_type: int, i_indice: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Split(CatSampledSplitType iType,
                | short iIndice)
                | 
                |     Returns or sets the Sampled object.

        :param int i_type: enum cat_sampled_split_type
        :param int i_indice:
        :rtype: None
        """
        return self.sampled.Split(i_type, i_indice)

    def __repr__(self):
        return f'Sampled(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.eno_cd5_interfaces.cd5_templates import CD5Templates
from pycatia.system_interfaces.any_object import AnyObject


class CD5TemplateType(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     CD5TemplateType
                | 
                | Represents a Template Type.
                | 
                | Properties on the object helps the users to get various templates and there
                | possible ENOVIA Types.
                | 
                | Example:
                | 
                |       The following example indicates how to retrieve the template
                |       type.
                |
                |      Dim oTemplateType As ENOIACD5TemplateType
                |      Set oTemplateType = oTemplateTypes.Item(1)
                |
                | See also:
                |     CD5TemplateTypes
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.cd5_template_type = com_object

    @property
    def possible_types(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property PossibleTypes() As CATSafeArrayVariant (Read Only)
                | 
                |     Returns (gets) the possible Types from a Template type.
                | 
                |     Example:
                | 
                |           The following example gets Possible ENOVIA Types from a Template
                |           type.
                |
                |          Dim oPossibleTypes As Array
                |          oPossibleTypes = oTemplateType.PossibleTypes

        :rtype: tuple
        """

        return self.cd5_template_type.PossibleTypes

    @property
    def template_type_name(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property TemplateTypeName() As CATBSTR (Read Only)
                | 
                |     Returns (gets) the name of the Template Type.
                | 
                |     Example:
                | 
                |           The following example gets the name of the Template
                |           Type.
                |
                |          Dim oName As CATBSTR
                |          oName = oTemplateType.TemplateTypeName

        :rtype: str
        """

        return self.cd5_template_type.TemplateTypeName

    @property
    def templates(self) -> CD5Templates:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Templates() As CD5Templates (Read Only)
                | 
                |     Returns (gets) the list of Templates from a Template type.
                | 
                |     Example:
                | 
                |           The following example gets Templates.
                |
                |          Dim oTemplates As ENOIACD5Templates
                |          Set oTemplates = oTemplateType.Templates

        :rtype: CD5Templates
        """

        return CD5Templates(self.cd5_template_type.Templates)

    def __repr__(self):
        return f'CD5TemplateType(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.mec_mod_interfaces.edge import Edge


class BiDimFeatEdge(Edge):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     InfInterfaces.Reference
                |                         MecModInterfaces.Boundary
                |                             MecModInterfaces.Edge
                |                                 BiDimFeatEdge
                | 
                | 1-D boundary belonging to a feature whose topological result is two
                | dimensional.
                | Role: This Boundary object may be, for example, the edge of a surface obtained
                | through the extrusion of a spline.
                | You will create a BiDimFeatEdge object using the Shapes.GetBoundary ,
                | HybridShapes.GetBoundary , Sketches.GetBoundary or Selection.SelectElement2
                | method. Then, you pass it to the operator (such as
                | HybridShapeFactory.AddNewPointOnCurveFromDistance ).
                | The lifetime of a BiDimFeatEdge object is limited, see
                | Boundary.
                | 
                | Example:
                |     This example asks the end user to select an edge, and creates a point on
                |     this edge. Here, both TriDimFeatEdge and BiDimFeatEdge objects are proposed to
                |     the user.
                | 
                |      Dim InputObjectType(1)
                |      Set Document = CATIA.ActiveDocument
                |      Set Selection = Document.Selection
                |      Set HybridBodies = Document.Part.HybridBodies
                |      Set HybridBody = HybridBodies.Item("Geometrical Set.1")
                |      'We propose to the user that he select an edge
                |      InputObjectType(0)="TriDimFeatEdge"
                |      InputObjectType(1)="BiDimFeatEdge"
                |      Status=Selection.SelectElement2(InputObjectType,"Select an
                |      edge",true)
                |      if (Status = "cancel") then Exit Sub
                |      Set Curve = Selection.Item(1).Value
                |      Set HybridShapePointOnCurve = HybridShapeFactory.AddNewPointOnCurveFromDistance(Curve,18.0,False)
                |      HybridBody.AppendHybridShape HybridShapePointOnCurve
                |      Document.Part.InWorkObject = HybridShapePointOnCurve
                |      Document.Part.Update 

    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.bi_dim_feat_edge = com_object

    def __repr__(self):
        return f'BiDimFeatEdge(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class SchApp2DZoneFrom3DZone(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SchApp2DZoneFrom3DZone
                | 
                | Manage a 2D zone that is dropped off from 3D counterpart.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sch_app_2d_zone_from_3d_zone = com_object

    def create_2d_app_zone(self) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Create2DAppZone() As AnyObject
                | 
                |     Create an Application Zone.
                | 
                |     Parameters:
                | 
                |         i3DZone
                |             The Bounded Zone (3D) object 
                |         oAppZone
                |             The new Application zone object created (CATISchAppZone interface
                |             pointer). 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchApp2DZoneFrom3DZone
                |          Dim objArg1 As AnyObject
                |           ...
                |          Set objArg1 = objThisIntf.Create2DAppZone

        :rtype: AnyObject
        """
        return AnyObject(self.sch_app_2d_zone_from_3d_zone.Create2DAppZone())

    def __repr__(self):
        return f'SchApp2DZoneFrom3DZone(name="{self.name}")'
